#line 1 "source/parser/TextFileParser.rl"
#include "parser/TextFile.h"
#include "Color.h"
#include <string.h>
#include <stdlib.h>
#include <cstddef>
#include <functional>
#include <vector>
#include <string>
#include <iostream>
using namespace std;
namespace text_file_parser
{
	struct FSM
	{
		public:
		int cs;
		char separator;
		int act;
		int top;
		char *ts;
		char *te;
		int stack[256];
		char buffer[8 * 1024];
		int line;
		int column;
		int line_start;
		int buffer_offset;
		int64_t number_i64;
		vector<int64_t> numbers_i64;
		char *number_double_start;
		vector<double> numbers_double;
		function<void(const Color&)> addColor;
		void handleNewline()
		{
			line++;
			column = 0;
			line_start = te - buffer;
		}
		int hexToInt(char hex)
		{
			if (hex >= '0' && hex <= '9') return hex - '0';
				if (hex >= 'a' && hex <= 'f') return hex - 'a' + 10;
				if (hex >= 'A' && hex <= 'F') return hex - 'A' + 10;
				return 0;
		}
		int hexPairToInt(const char *hex_pair)
		{
			return hexToInt(hex_pair[0]) << 4 | hexToInt(hex_pair[1]);
		}
		void colorHexFull(bool with_hash_symbol)
		{
			Color color;
			int start_index = with_hash_symbol ? 1 : 0;
			color.rgb.red = hexPairToInt(ts + start_index) / 255.0;
			color.rgb.green = hexPairToInt(ts + start_index + 2) / 255.0;
			color.rgb.blue = hexPairToInt(ts + start_index + 4) / 255.0;
			addColor(color);
		}
		void colorHexShort(bool with_hash_symbol)
		{
			Color color;
			int start_index = with_hash_symbol ? 1 : 0;
			color.rgb.red = hexToInt(ts[start_index + 0]) / 15.0;
			color.rgb.green = hexToInt(ts[start_index + 1]) / 15.0;
			color.rgb.blue = hexToInt(ts[start_index + 2]) / 15.0;
			color.ma[3] = 0;
			addColor(color);
		}
		void colorRgb()
		{
			Color color;
			color.rgb.red = numbers_i64[0] / 255.0;
			color.rgb.green = numbers_i64[1] / 255.0;
			color.rgb.blue = numbers_i64[2] / 255.0;
			color.ma[3] = 0;
			numbers_i64.clear();
			addColor(color);
		}
		void colorRgba()
		{
			Color color;
			color.rgb.red = numbers_i64[0] / 255.0;
			color.rgb.green = numbers_i64[1] / 255.0;
			color.rgb.blue = numbers_i64[2] / 255.0;
			color.ma[3] = numbers_double[0];
			numbers_i64.clear();
			numbers_double.clear();
			addColor(color);
		}
		void colorValues()
		{
			Color color;
			color.rgb.red = numbers_double[0];
			color.rgb.green = numbers_double[1];
			color.rgb.blue = numbers_double[2];
			color.ma[3] = 0;
			numbers_double.clear();
			addColor(color);
		}
		void colorValueIntegers()
		{
			Color color;
			color.rgb.red = numbers_i64[0] / 255.0;
			color.rgb.green = numbers_i64[1] / 255.0;
			color.rgb.blue = numbers_i64[2] / 255.0;
			color.ma[3] = 0;
			numbers_i64.clear();
			addColor(color);
		}
		double parseDouble(const char *start, const char *end)
		{
			string v(start, end);
			return stod(v.c_str());
		}
		void clearNumberStacks()
		{
			numbers_i64.clear();
			numbers_double.clear();
		}
	};
	
	
	
#line 155 "source/parser/TextFileParser.rl"
	
	
	
#line 130 "/builddir/build/BUILD/gpick-3b17cf9e8b8514bdf16c49ca970e6f47da34e6ae/CMakeFiles/TextFileParser.cpp"
	static const signed char _text_file_actions[] = {
		0, 1, 1, 1, 2, 1, 3, 1,
		4, 1, 5, 1, 6, 1, 7, 1,
		8, 1, 9, 1, 10, 1, 19, 1,
		20, 1, 21, 1, 22, 1, 23, 1,
		27, 1, 28, 1, 29, 1, 30, 1,
		31, 1, 32, 1, 33, 1, 34, 1,
		35, 2, 0, 1, 2, 2, 4, 2,
		2, 20, 2, 2, 25, 2, 4, 21,
		2, 4, 26, 2, 10, 11, 2, 10,
		12, 2, 10, 14, 2, 10, 15, 2,
		10, 16, 2, 10, 17, 2, 10, 18,
		3, 0, 1, 3, 3, 2, 4, 24,
		3, 10, 1, 13, 3, 10, 1, 18,
		3, 10, 3, 14, 3, 10, 3, 17,
		3, 10, 11, 1, 3, 10, 12, 1,
		5, 10, 0, 1, 3, 18, 5, 10,
		0, 1, 13, 3, 0
	};
	
	static const short _text_file_key_offsets[] = {
		0, 0, 6, 12, 18, 24, 32, 36,
		44, 47, 49, 57, 61, 69, 72, 74,
		78, 80, 84, 86, 92, 101, 105, 107,
		113, 122, 124, 130, 138, 147, 151, 159,
		164, 169, 174, 180, 184, 189, 195, 199,
		204, 210, 214, 219, 225, 229, 234, 240,
		244, 249, 255, 259, 267, 270, 272, 280,
		284, 288, 290, 296, 305, 307, 310, 311,
		337, 347, 350, 354, 362, 376, 382, 393,
		403, 407, 409, 414, 424, 445, 450, 452,
		473, 494, 515, 536, 553, 567, 581, 597,
		615, 631, 649, 667, 683, 701, 719, 735,
		753, 771, 787, 799, 811, 824, 835, 835,
		0
	};
	
	static const char _text_file_trans_keys[] = {
		48, 57, 65, 70, 97, 102, 48, 57,
		65, 70, 97, 102, 48, 57, 65, 70,
		97, 102, 48, 57, 65, 70, 97, 102,
		32, 44, 69, 101, 9, 13, 48, 57,
		32, 44, 9, 13, 32, 43, 45, 46,
		9, 13, 48, 57, 46, 48, 57, 48,
		57, 32, 44, 69, 101, 9, 13, 48,
		57, 32, 44, 9, 13, 32, 43, 45,
		46, 9, 13, 48, 57, 46, 48, 57,
		48, 57, 43, 45, 48, 57, 48, 57,
		43, 45, 48, 57, 48, 57, 32, 44,
		9, 13, 48, 57, 32, 44, 46, 69,
		101, 9, 13, 48, 57, 43, 45, 48,
		57, 48, 57, 32, 44, 9, 13, 48,
		57, 32, 44, 46, 69, 101, 9, 13,
		48, 57, 48, 57, 32, 44, 9, 13,
		48, 57, 32, 43, 45, 46, 9, 13,
		48, 57, 32, 44, 46, 69, 101, 9,
		13, 48, 57, 32, 44, 9, 13, 32,
		43, 45, 46, 9, 13, 48, 57, 32,
		9, 13, 48, 57, 32, 9, 13, 48,
		57, 32, 9, 13, 48, 57, 32, 44,
		9, 13, 48, 57, 32, 44, 9, 13,
		32, 9, 13, 48, 57, 32, 44, 9,
		13, 48, 57, 32, 44, 9, 13, 32,
		9, 13, 48, 57, 32, 41, 9, 13,
		48, 57, 32, 41, 9, 13, 32, 9,
		13, 48, 57, 32, 44, 9, 13, 48,
		57, 32, 44, 9, 13, 32, 9, 13,
		48, 57, 32, 44, 9, 13, 48, 57,
		32, 44, 9, 13, 32, 9, 13, 48,
		57, 32, 44, 9, 13, 48, 57, 32,
		44, 9, 13, 32, 43, 45, 46, 9,
		13, 48, 57, 46, 48, 57, 48, 57,
		32, 41, 69, 101, 9, 13, 48, 57,
		32, 41, 9, 13, 43, 45, 48, 57,
		48, 57, 32, 41, 9, 13, 48, 57,
		32, 41, 46, 69, 101, 9, 13, 48,
		57, 10, 42, 10, 42, 47, 10, 10,
		13, 32, 35, 43, 45, 46, 47, 82,
		114, 9, 12, 33, 44, 48, 57, 58,
		64, 65, 70, 91, 96, 97, 102, 123,
		126, 9, 13, 32, 47, 58, 64, 91,
		96, 123, 126, 32, 9, 13, 10, 32,
		9, 13, 33, 47, 58, 64, 91, 96,
		123, 126, 33, 47, 48, 57, 58, 64,
		65, 70, 91, 96, 97, 102, 123, 126,
		48, 57, 65, 70, 97, 102, 46, 33,
		47, 48, 57, 58, 64, 91, 96, 123,
		126, 33, 47, 48, 57, 58, 64, 91,
		96, 123, 126, 69, 101, 48, 57, 48,
		57, 46, 69, 101, 48, 57, 42, 47,
		33, 46, 58, 64, 91, 96, 123, 126,
		32, 44, 46, 69, 101, 9, 13, 33,
		47, 48, 57, 58, 64, 65, 70, 91,
		96, 97, 102, 123, 126, 46, 69, 101,
		48, 57, 48, 57, 32, 44, 46, 69,
		101, 9, 13, 33, 47, 48, 57, 58,
		64, 65, 70, 91, 96, 97, 102, 123,
		126, 32, 44, 46, 69, 101, 9, 13,
		33, 47, 48, 57, 58, 64, 65, 70,
		91, 96, 97, 102, 123, 126, 32, 44,
		46, 69, 101, 9, 13, 33, 47, 48,
		57, 58, 64, 65, 70, 91, 96, 97,
		102, 123, 126, 32, 44, 46, 69, 101,
		9, 13, 33, 47, 48, 57, 58, 64,
		65, 70, 91, 96, 97, 102, 123, 126,
		32, 44, 46, 69, 101, 9, 13, 33,
		47, 48, 57, 58, 64, 91, 96, 123,
		126, 43, 45, 9, 13, 32, 47, 48,
		57, 58, 64, 91, 96, 123, 126, 32,
		44, 9, 13, 33, 47, 48, 57, 58,
		64, 91, 96, 123, 126, 9, 13, 32,
		47, 48, 57, 58, 64, 65, 70, 91,
		96, 97, 102, 123, 126, 43, 45, 9,
		13, 32, 47, 48, 57, 58, 64, 65,
		70, 91, 96, 97, 102, 123, 126, 9,
		13, 32, 47, 48, 57, 58, 64, 65,
		70, 91, 96, 97, 102, 123, 126, 43,
		45, 9, 13, 32, 47, 48, 57, 58,
		64, 65, 70, 91, 96, 97, 102, 123,
		126, 32, 44, 9, 13, 33, 47, 48,
		57, 58, 64, 65, 70, 91, 96, 97,
		102, 123, 126, 9, 13, 32, 47, 48,
		57, 58, 64, 65, 70, 91, 96, 97,
		102, 123, 126, 43, 45, 9, 13, 32,
		47, 48, 57, 58, 64, 65, 70, 91,
		96, 97, 102, 123, 126, 32, 44, 9,
		13, 33, 47, 48, 57, 58, 64, 65,
		70, 91, 96, 97, 102, 123, 126, 9,
		13, 32, 47, 48, 57, 58, 64, 65,
		70, 91, 96, 97, 102, 123, 126, 43,
		45, 9, 13, 32, 47, 48, 57, 58,
		64, 65, 70, 91, 96, 97, 102, 123,
		126, 32, 44, 9, 13, 33, 47, 48,
		57, 58, 64, 65, 70, 91, 96, 97,
		102, 123, 126, 9, 13, 32, 47, 48,
		57, 58, 64, 65, 70, 91, 96, 97,
		102, 123, 126, 71, 103, 9, 13, 32,
		47, 58, 64, 91, 96, 123, 126, 66,
		98, 9, 13, 32, 47, 58, 64, 91,
		96, 123, 126, 40, 65, 97, 9, 13,
		32, 47, 58, 64, 91, 96, 123, 126,
		40, 9, 13, 32, 47, 58, 64, 91,
		96, 123, 126, 0
	};
	
	static const signed char _text_file_single_lengths[] = {
		0, 0, 0, 0, 0, 4, 2, 4,
		1, 0, 4, 2, 4, 1, 0, 2,
		0, 2, 0, 2, 5, 2, 0, 2,
		5, 0, 2, 4, 5, 2, 4, 1,
		1, 1, 2, 2, 1, 2, 2, 1,
		2, 2, 1, 2, 2, 1, 2, 2,
		1, 2, 2, 4, 1, 0, 4, 2,
		2, 0, 2, 5, 2, 3, 1, 10,
		0, 1, 2, 0, 0, 0, 1, 0,
		2, 0, 3, 2, 5, 3, 0, 5,
		5, 5, 5, 5, 2, 2, 0, 2,
		0, 2, 2, 0, 2, 2, 0, 2,
		2, 0, 2, 2, 3, 1, 0, 0,
		0
	};
	
	static const signed char _text_file_range_lengths[] = {
		0, 3, 3, 3, 3, 2, 1, 2,
		1, 1, 2, 1, 2, 1, 1, 1,
		1, 1, 1, 2, 2, 1, 1, 2,
		2, 1, 2, 2, 2, 1, 2, 2,
		2, 2, 2, 1, 2, 2, 1, 2,
		2, 1, 2, 2, 1, 2, 2, 1,
		2, 2, 1, 2, 1, 1, 2, 1,
		1, 1, 2, 2, 0, 0, 0, 8,
		5, 1, 1, 4, 7, 3, 5, 5,
		1, 1, 1, 4, 8, 1, 1, 8,
		8, 8, 8, 6, 6, 6, 8, 8,
		8, 8, 8, 8, 8, 8, 8, 8,
		8, 8, 5, 5, 5, 5, 0, 0,
		0
	};
	
	static const short _text_file_index_offsets[] = {
		0, 0, 4, 8, 12, 16, 23, 27,
		34, 37, 39, 46, 50, 57, 60, 62,
		66, 68, 72, 74, 79, 87, 91, 93,
		98, 106, 108, 113, 120, 128, 132, 139,
		143, 147, 151, 156, 160, 164, 169, 173,
		177, 182, 186, 190, 195, 199, 203, 208,
		212, 216, 221, 225, 232, 235, 237, 244,
		248, 252, 254, 259, 267, 270, 274, 276,
		295, 301, 304, 308, 313, 321, 325, 332,
		338, 342, 344, 349, 356, 370, 375, 377,
		391, 405, 419, 433, 445, 454, 463, 472,
		483, 492, 503, 514, 523, 534, 545, 554,
		565, 576, 585, 593, 601, 610, 617, 618,
		0
	};
	
	static const signed char _text_file_cond_targs[] = {
		2, 2, 2, 63, 69, 69, 69, 63,
		4, 4, 4, 63, 63, 63, 63, 63,
		6, 7, 21, 21, 6, 5, 63, 6,
		7, 6, 63, 7, 8, 8, 9, 7,
		20, 63, 9, 20, 63, 10, 63, 11,
		12, 17, 17, 11, 10, 63, 11, 12,
		11, 63, 12, 13, 13, 14, 12, 74,
		63, 14, 74, 63, 72, 63, 16, 16,
		73, 63, 73, 63, 18, 18, 19, 63,
		19, 63, 11, 12, 11, 19, 63, 11,
		12, 9, 17, 17, 11, 20, 63, 22,
		22, 23, 63, 23, 63, 6, 7, 6,
		23, 63, 6, 7, 25, 21, 21, 6,
		24, 63, 5, 63, 26, 27, 26, 31,
		63, 27, 8, 8, 9, 27, 28, 63,
		29, 30, 9, 17, 17, 29, 28, 63,
		29, 30, 29, 63, 30, 13, 13, 14,
		30, 77, 63, 32, 32, 31, 63, 32,
		32, 78, 63, 33, 33, 34, 63, 35,
		36, 35, 34, 63, 35, 36, 35, 63,
		36, 36, 37, 63, 38, 39, 38, 37,
		63, 38, 39, 38, 63, 39, 39, 40,
		63, 41, 63, 41, 40, 63, 41, 63,
		41, 63, 42, 42, 43, 63, 44, 45,
		44, 43, 63, 44, 45, 44, 63, 45,
		45, 46, 63, 47, 48, 47, 46, 63,
		47, 48, 47, 63, 48, 48, 49, 63,
		50, 51, 50, 49, 63, 50, 51, 50,
		63, 51, 52, 52, 53, 51, 59, 63,
		53, 59, 63, 54, 63, 55, 63, 56,
		56, 55, 54, 63, 55, 63, 55, 63,
		57, 57, 58, 63, 58, 63, 55, 63,
		55, 58, 63, 55, 63, 53, 56, 56,
		55, 59, 63, 60, 61, 60, 60, 61,
		102, 60, 103, 62, 65, 66, 65, 68,
		70, 70, 71, 75, 98, 98, 65, 67,
		76, 67, 97, 67, 97, 67, 64, 63,
		63, 63, 63, 63, 64, 65, 65, 63,
		65, 65, 65, 63, 67, 67, 67, 67,
		63, 67, 1, 67, 1, 67, 1, 67,
		63, 3, 3, 3, 63, 71, 67, 24,
		67, 67, 67, 63, 67, 5, 67, 67,
		67, 63, 15, 15, 72, 63, 73, 63,
		14, 15, 15, 74, 63, 67, 67, 67,
		67, 67, 67, 63, 26, 27, 25, 95,
		95, 26, 63, 79, 63, 94, 63, 94,
		63, 64, 14, 15, 15, 77, 63, 78,
		63, 26, 27, 25, 92, 92, 26, 63,
		80, 63, 91, 63, 91, 63, 64, 26,
		27, 25, 89, 89, 26, 63, 81, 63,
		88, 63, 88, 63, 64, 26, 27, 25,
		87, 87, 26, 63, 82, 63, 86, 63,
		86, 63, 64, 26, 27, 25, 84, 84,
		26, 63, 83, 63, 64, 63, 64, 63,
		64, 26, 27, 25, 84, 84, 26, 63,
		83, 63, 63, 63, 64, 22, 22, 63,
		63, 85, 63, 63, 63, 64, 6, 7,
		6, 63, 85, 63, 63, 63, 64, 63,
		63, 64, 63, 64, 63, 64, 63, 64,
		22, 22, 63, 63, 85, 63, 64, 63,
		64, 63, 64, 63, 63, 86, 63, 86,
		63, 86, 63, 64, 22, 22, 63, 63,
		90, 63, 86, 63, 86, 63, 64, 6,
		7, 6, 63, 85, 63, 64, 63, 64,
		63, 64, 63, 63, 88, 63, 88, 63,
		88, 63, 64, 22, 22, 63, 63, 93,
		63, 88, 63, 88, 63, 64, 6, 7,
		6, 63, 90, 63, 86, 63, 86, 63,
		64, 63, 63, 91, 63, 91, 63, 91,
		63, 64, 22, 22, 63, 63, 96, 63,
		91, 63, 91, 63, 64, 6, 7, 6,
		63, 93, 63, 88, 63, 88, 63, 64,
		63, 63, 94, 63, 94, 63, 94, 63,
		64, 99, 99, 63, 63, 63, 63, 63,
		64, 100, 100, 63, 63, 63, 63, 63,
		64, 33, 101, 101, 63, 63, 63, 63,
		63, 64, 42, 63, 63, 63, 63, 63,
		64, 0, 0, 0, 63, 63, 63, 63,
		63, 63, 63, 63, 63, 63, 63, 63,
		63, 63, 63, 63, 63, 63, 63, 63,
		63, 63, 63, 63, 63, 63, 63, 63,
		63, 63, 63, 63, 63, 63, 63, 63,
		63, 63, 63, 63, 63, 63, 63, 63,
		63, 63, 63, 63, 63, 63, 63, 63,
		63, 63, 63, 63, 63, 63, 63, 60,
		61, 62, 63, 63, 63, 63, 63, 63,
		63, 63, 63, 63, 63, 63, 63, 63,
		63, 63, 63, 63, 63, 63, 63, 63,
		63, 63, 63, 63, 63, 63, 63, 63,
		63, 63, 63, 63, 63, 63, 63, 63,
		63, 102, 103, 0
	};
	
	static const signed char _text_file_cond_actions[] = {
		0, 0, 0, 41, 19, 19, 19, 41,
		0, 0, 0, 39, 21, 21, 21, 39,
		7, 7, 0, 0, 7, 0, 47, 0,
		0, 0, 47, 0, 5, 5, 5, 0,
		5, 47, 0, 0, 47, 0, 47, 7,
		7, 0, 0, 7, 0, 47, 0, 0,
		0, 47, 0, 5, 5, 5, 0, 104,
		47, 0, 73, 47, 73, 47, 0, 0,
		0, 47, 0, 47, 0, 0, 0, 47,
		0, 47, 7, 7, 7, 0, 47, 7,
		7, 0, 0, 0, 7, 0, 47, 0,
		0, 0, 47, 0, 47, 7, 7, 7,
		0, 47, 7, 7, 0, 0, 0, 7,
		0, 43, 0, 47, 0, 0, 0, 49,
		47, 0, 5, 5, 5, 0, 88, 47,
		52, 52, 0, 0, 0, 52, 1, 47,
		0, 0, 0, 47, 0, 5, 5, 5,
		0, 126, 47, 3, 3, 1, 47, 0,
		0, 49, 47, 0, 0, 49, 45, 3,
		3, 3, 1, 45, 0, 0, 0, 45,
		0, 0, 49, 45, 3, 3, 3, 1,
		45, 0, 0, 0, 45, 0, 0, 49,
		45, 3, 55, 3, 1, 45, 0, 23,
		0, 45, 0, 0, 49, 45, 3, 3,
		3, 1, 45, 0, 0, 0, 45, 0,
		0, 49, 45, 3, 3, 3, 1, 45,
		0, 0, 0, 45, 0, 0, 49, 45,
		3, 3, 3, 1, 45, 0, 0, 0,
		45, 0, 5, 5, 5, 0, 5, 45,
		0, 0, 45, 0, 45, 7, 61, 0,
		0, 7, 0, 45, 0, 25, 0, 45,
		0, 0, 0, 45, 0, 45, 7, 61,
		7, 0, 45, 7, 61, 0, 0, 0,
		7, 0, 45, 9, 0, 0, 9, 0,
		11, 0, 13, 0, 9, 0, 0, 19,
		108, 108, 108, 0, 0, 0, 0, 82,
		120, 82, 0, 82, 0, 82, 85, 47,
		47, 47, 47, 47, 85, 0, 0, 33,
		9, 0, 0, 33, 82, 82, 82, 82,
		47, 82, 0, 82, 0, 82, 0, 82,
		31, 0, 0, 0, 27, 82, 82, 0,
		82, 82, 82, 35, 82, 0, 82, 82,
		82, 35, 0, 0, 73, 64, 0, 64,
		0, 0, 0, 73, 64, 79, 76, 82,
		82, 82, 82, 35, 52, 52, 0, 85,
		85, 52, 37, 100, 37, 0, 37, 0,
		37, 85, 3, 3, 3, 96, 92, 1,
		58, 52, 52, 0, 70, 70, 52, 37,
		116, 37, 0, 37, 0, 37, 85, 52,
		52, 0, 85, 85, 52, 29, 100, 29,
		0, 29, 0, 29, 85, 52, 52, 0,
		85, 85, 52, 37, 100, 37, 0, 37,
		0, 37, 85, 52, 52, 0, 67, 67,
		52, 37, 112, 37, 67, 37, 67, 37,
		85, 52, 52, 0, 85, 85, 52, 47,
		100, 47, 47, 47, 85, 0, 0, 47,
		47, 85, 47, 47, 47, 85, 7, 7,
		7, 47, 85, 47, 47, 47, 85, 37,
		37, 67, 37, 67, 37, 67, 37, 85,
		0, 0, 37, 37, 67, 37, 67, 37,
		67, 37, 85, 37, 37, 0, 37, 0,
		37, 0, 37, 85, 0, 0, 37, 37,
		85, 37, 0, 37, 0, 37, 85, 7,
		7, 7, 37, 67, 37, 67, 37, 67,
		37, 85, 29, 29, 0, 29, 0, 29,
		0, 29, 85, 0, 0, 29, 29, 85,
		29, 0, 29, 0, 29, 85, 7, 7,
		7, 37, 85, 37, 0, 37, 0, 37,
		85, 37, 37, 0, 37, 0, 37, 0,
		37, 85, 0, 0, 37, 37, 70, 37,
		0, 37, 0, 37, 85, 7, 7, 7,
		29, 85, 29, 0, 29, 0, 29, 85,
		37, 37, 0, 37, 0, 37, 0, 37,
		85, 0, 0, 37, 37, 37, 37, 37,
		85, 19, 19, 37, 37, 37, 37, 37,
		85, 0, 19, 19, 37, 37, 37, 37,
		37, 85, 0, 37, 37, 37, 37, 37,
		85, 0, 0, 0, 41, 41, 39, 39,
		47, 47, 47, 47, 47, 47, 47, 47,
		47, 47, 47, 47, 47, 47, 47, 47,
		47, 47, 47, 43, 47, 47, 47, 47,
		47, 47, 47, 47, 45, 45, 45, 45,
		45, 45, 45, 45, 45, 45, 45, 45,
		45, 45, 45, 45, 45, 45, 45, 45,
		45, 45, 45, 45, 45, 45, 45, 0,
		0, 0, 0, 47, 33, 33, 47, 31,
		27, 35, 35, 64, 64, 64, 35, 37,
		92, 58, 37, 29, 37, 37, 47, 47,
		47, 37, 37, 37, 37, 37, 29, 29,
		37, 37, 37, 29, 37, 37, 37, 37,
		37, 0, 0, 0
	};
	
	static const signed char _text_file_to_state_actions[] = {
		0, 0, 0, 0, 0, 0, 0, 0,
		0, 0, 0, 0, 0, 0, 0, 0,
		0, 0, 0, 0, 0, 0, 0, 0,
		0, 0, 0, 0, 0, 0, 0, 0,
		0, 0, 0, 0, 0, 0, 0, 0,
		0, 0, 0, 0, 0, 0, 0, 0,
		0, 0, 0, 0, 0, 0, 0, 0,
		0, 0, 0, 0, 15, 0, 15, 15,
		0, 0, 0, 0, 0, 0, 0, 0,
		0, 0, 0, 0, 0, 0, 0, 0,
		0, 0, 0, 0, 0, 0, 0, 0,
		0, 0, 0, 0, 0, 0, 0, 0,
		0, 0, 0, 0, 0, 0, 0, 0,
		0
	};
	
	static const signed char _text_file_from_state_actions[] = {
		0, 0, 0, 0, 0, 0, 0, 0,
		0, 0, 0, 0, 0, 0, 0, 0,
		0, 0, 0, 0, 0, 0, 0, 0,
		0, 0, 0, 0, 0, 0, 0, 0,
		0, 0, 0, 0, 0, 0, 0, 0,
		0, 0, 0, 0, 0, 0, 0, 0,
		0, 0, 0, 0, 0, 0, 0, 0,
		0, 0, 0, 0, 0, 0, 0, 17,
		0, 0, 0, 0, 0, 0, 0, 0,
		0, 0, 0, 0, 0, 0, 0, 0,
		0, 0, 0, 0, 0, 0, 0, 0,
		0, 0, 0, 0, 0, 0, 0, 0,
		0, 0, 0, 0, 0, 0, 0, 0,
		0
	};
	
	static const short _text_file_eof_trans[] = {
		620, 621, 622, 623, 624, 625, 626, 627,
		628, 629, 630, 631, 632, 633, 634, 635,
		636, 637, 638, 639, 640, 641, 642, 643,
		644, 645, 646, 647, 648, 649, 650, 651,
		652, 653, 654, 655, 656, 657, 658, 659,
		660, 661, 662, 663, 664, 665, 666, 667,
		668, 669, 670, 671, 672, 673, 674, 675,
		676, 677, 678, 679, 680, 681, 682, 683,
		684, 685, 686, 687, 688, 689, 690, 691,
		692, 693, 694, 695, 696, 697, 698, 699,
		700, 701, 702, 703, 704, 705, 706, 707,
		708, 709, 710, 711, 712, 713, 714, 715,
		716, 717, 718, 719, 720, 721, 722, 723,
		0
	};
	
	static const int text_file_start = 63;
	static const int text_file_first_final = 63;
	static const int text_file_error = 0;
	
	static const int text_file_en_multi_line_comment = 60;
	static const int text_file_en_single_line_comment = 62;
	static const int text_file_en_main = 63;
	
	
#line 157 "source/parser/TextFileParser.rl"
	
	
	bool scanner(TextFile &text_file, const Configuration &configuration)
	{
		FSM fsm_struct;
		FSM *fsm = &fsm_struct;
		fsm->ts = 0;
		fsm->te = 0;
		fsm->line = 0;
		fsm->line_start = 0;
		fsm->column = 0;
		fsm->buffer_offset = 0;
		bool parse_error = false;
		fsm->addColor = [&text_file](const Color &color){
			Color c = color;
			color_rgb_normalize(&c);
			text_file.addColor(c);
		};
		
#line 595 "/builddir/build/BUILD/gpick-3b17cf9e8b8514bdf16c49ca970e6f47da34e6ae/CMakeFiles/TextFileParser.cpp"
		{
			fsm->cs = (int)text_file_start;
			fsm->ts = 0;
			fsm->te = 0;
			fsm->act = 0;
		}
		
#line 175 "source/parser/TextFileParser.rl"
		
		int have = 0;
		while (1){
			char *p = fsm->buffer + have;
			int space = sizeof(fsm->buffer) - have;
			if (space == 0){
				text_file.outOfMemory();
				break;
			}
			char *eof = 0;
			auto read_size = text_file.read(fsm->buffer + have, space);
			char *pe = p + read_size;
			if (read_size > 0){
				if (read_size < sizeof(fsm->buffer)) eof = pe;
					
#line 619 "/builddir/build/BUILD/gpick-3b17cf9e8b8514bdf16c49ca970e6f47da34e6ae/CMakeFiles/TextFileParser.cpp"
				{
					int _klen;
					unsigned int _trans = 0;
					const char * _keys;
					const signed char * _acts;
					unsigned int _nacts;
					_resume: {}
					if ( p == pe && p != eof )
						goto _out;
					_acts = ( _text_file_actions + (_text_file_from_state_actions[fsm->cs]));
					_nacts = (unsigned int)(*( _acts));
					_acts += 1;
					while ( _nacts > 0 ) {
						switch ( (*( _acts)) ) {
							case 9:  {
								{
#line 1 "NONE"
									{fsm->ts = p;}}
								
#line 639 "/builddir/build/BUILD/gpick-3b17cf9e8b8514bdf16c49ca970e6f47da34e6ae/CMakeFiles/TextFileParser.cpp"
								
								break; 
							}
						}
						_nacts -= 1;
						_acts += 1;
					}
					
					if ( p == eof ) {
						if ( _text_file_eof_trans[fsm->cs] > 0 ) {
							_trans = (unsigned int)_text_file_eof_trans[fsm->cs] - 1;
						}
					}
					else {
						_keys = ( _text_file_trans_keys + (_text_file_key_offsets[fsm->cs]));
						_trans = (unsigned int)_text_file_index_offsets[fsm->cs];
						
						_klen = (int)_text_file_single_lengths[fsm->cs];
						if ( _klen > 0 ) {
							const char *_lower = _keys;
							const char *_upper = _keys + _klen - 1;
							const char *_mid;
							while ( 1 ) {
								if ( _upper < _lower ) {
									_keys += _klen;
									_trans += (unsigned int)_klen;
									break;
								}
								
								_mid = _lower + ((_upper-_lower) >> 1);
								if ( ( (*( p))) < (*( _mid)) )
									_upper = _mid - 1;
								else if ( ( (*( p))) > (*( _mid)) )
									_lower = _mid + 1;
								else {
									_trans += (unsigned int)(_mid - _keys);
									goto _match;
								}
							}
						}
						
						_klen = (int)_text_file_range_lengths[fsm->cs];
						if ( _klen > 0 ) {
							const char *_lower = _keys;
							const char *_upper = _keys + (_klen<<1) - 2;
							const char *_mid;
							while ( 1 ) {
								if ( _upper < _lower ) {
									_trans += (unsigned int)_klen;
									break;
								}
								
								_mid = _lower + (((_upper-_lower) >> 1) & ~1);
								if ( ( (*( p))) < (*( _mid)) )
									_upper = _mid - 2;
								else if ( ( (*( p))) > (*( _mid + 1)) )
									_lower = _mid + 2;
								else {
									_trans += (unsigned int)((_mid - _keys)>>1);
									break;
								}
							}
						}
						
						_match: {}
					}
					fsm->cs = (int)_text_file_cond_targs[_trans];
					
					if ( _text_file_cond_actions[_trans] != 0 ) {
						
						_acts = ( _text_file_actions + (_text_file_cond_actions[_trans]));
						_nacts = (unsigned int)(*( _acts));
						_acts += 1;
						while ( _nacts > 0 ) {
							switch ( (*( _acts)) )
							{
								case 0:  {
									{
#line 126 "source/parser/TextFileParser.rl"
										fsm->number_i64 = 0; }
									
#line 721 "/builddir/build/BUILD/gpick-3b17cf9e8b8514bdf16c49ca970e6f47da34e6ae/CMakeFiles/TextFileParser.cpp"
									
									break; 
								}
								case 1:  {
									{
#line 126 "source/parser/TextFileParser.rl"
										fsm->number_i64 = fsm->number_i64 * 10 + (*p - '0'); }
									
#line 730 "/builddir/build/BUILD/gpick-3b17cf9e8b8514bdf16c49ca970e6f47da34e6ae/CMakeFiles/TextFileParser.cpp"
									
									break; 
								}
								case 2:  {
									{
#line 129 "source/parser/TextFileParser.rl"
										fsm->numbers_i64.push_back(fsm->number_i64); }
									
#line 739 "/builddir/build/BUILD/gpick-3b17cf9e8b8514bdf16c49ca970e6f47da34e6ae/CMakeFiles/TextFileParser.cpp"
									
									break; 
								}
								case 3:  {
									{
#line 130 "source/parser/TextFileParser.rl"
										fsm->number_double_start = p; }
									
#line 748 "/builddir/build/BUILD/gpick-3b17cf9e8b8514bdf16c49ca970e6f47da34e6ae/CMakeFiles/TextFileParser.cpp"
									
									break; 
								}
								case 4:  {
									{
#line 130 "source/parser/TextFileParser.rl"
										fsm->numbers_double.push_back(fsm->parseDouble(fsm->number_double_start, p)); }
									
#line 757 "/builddir/build/BUILD/gpick-3b17cf9e8b8514bdf16c49ca970e6f47da34e6ae/CMakeFiles/TextFileParser.cpp"
									
									break; 
								}
								case 5:  {
									{
#line 132 "source/parser/TextFileParser.rl"
										fsm->handleNewline(); }
									
#line 766 "/builddir/build/BUILD/gpick-3b17cf9e8b8514bdf16c49ca970e6f47da34e6ae/CMakeFiles/TextFileParser.cpp"
									
									break; 
								}
								case 6:  {
									{
#line 134 "source/parser/TextFileParser.rl"
										{fsm->cs = 63;goto _again;}}
									
#line 775 "/builddir/build/BUILD/gpick-3b17cf9e8b8514bdf16c49ca970e6f47da34e6ae/CMakeFiles/TextFileParser.cpp"
									
									break; 
								}
								case 7:  {
									{
#line 135 "source/parser/TextFileParser.rl"
										{fsm->cs = 63;goto _again;}}
									
#line 784 "/builddir/build/BUILD/gpick-3b17cf9e8b8514bdf16c49ca970e6f47da34e6ae/CMakeFiles/TextFileParser.cpp"
									
									break; 
								}
								case 10:  {
									{
#line 1 "NONE"
										{fsm->te = p+1;}}
									
#line 793 "/builddir/build/BUILD/gpick-3b17cf9e8b8514bdf16c49ca970e6f47da34e6ae/CMakeFiles/TextFileParser.cpp"
									
									break; 
								}
								case 11:  {
									{
#line 140 "source/parser/TextFileParser.rl"
										{fsm->act = 3;}}
									
#line 802 "/builddir/build/BUILD/gpick-3b17cf9e8b8514bdf16c49ca970e6f47da34e6ae/CMakeFiles/TextFileParser.cpp"
									
									break; 
								}
								case 12:  {
									{
#line 141 "source/parser/TextFileParser.rl"
										{fsm->act = 4;}}
									
#line 811 "/builddir/build/BUILD/gpick-3b17cf9e8b8514bdf16c49ca970e6f47da34e6ae/CMakeFiles/TextFileParser.cpp"
									
									break; 
								}
								case 13:  {
									{
#line 144 "source/parser/TextFileParser.rl"
										{fsm->act = 7;}}
									
#line 820 "/builddir/build/BUILD/gpick-3b17cf9e8b8514bdf16c49ca970e6f47da34e6ae/CMakeFiles/TextFileParser.cpp"
									
									break; 
								}
								case 14:  {
									{
#line 146 "source/parser/TextFileParser.rl"
										{fsm->act = 9;}}
									
#line 829 "/builddir/build/BUILD/gpick-3b17cf9e8b8514bdf16c49ca970e6f47da34e6ae/CMakeFiles/TextFileParser.cpp"
									
									break; 
								}
								case 15:  {
									{
#line 147 "source/parser/TextFileParser.rl"
										{fsm->act = 10;}}
									
#line 838 "/builddir/build/BUILD/gpick-3b17cf9e8b8514bdf16c49ca970e6f47da34e6ae/CMakeFiles/TextFileParser.cpp"
									
									break; 
								}
								case 16:  {
									{
#line 148 "source/parser/TextFileParser.rl"
										{fsm->act = 11;}}
									
#line 847 "/builddir/build/BUILD/gpick-3b17cf9e8b8514bdf16c49ca970e6f47da34e6ae/CMakeFiles/TextFileParser.cpp"
									
									break; 
								}
								case 17:  {
									{
#line 151 "source/parser/TextFileParser.rl"
										{fsm->act = 14;}}
									
#line 856 "/builddir/build/BUILD/gpick-3b17cf9e8b8514bdf16c49ca970e6f47da34e6ae/CMakeFiles/TextFileParser.cpp"
									
									break; 
								}
								case 18:  {
									{
#line 152 "source/parser/TextFileParser.rl"
										{fsm->act = 15;}}
									
#line 865 "/builddir/build/BUILD/gpick-3b17cf9e8b8514bdf16c49ca970e6f47da34e6ae/CMakeFiles/TextFileParser.cpp"
									
									break; 
								}
								case 19:  {
									{
#line 138 "source/parser/TextFileParser.rl"
										{fsm->te = p+1;{
#line 138 "source/parser/TextFileParser.rl"
												if (configuration.full_hex) fsm->colorHexFull(true); }
										}}
									
#line 877 "/builddir/build/BUILD/gpick-3b17cf9e8b8514bdf16c49ca970e6f47da34e6ae/CMakeFiles/TextFileParser.cpp"
									
									break; 
								}
								case 20:  {
									{
#line 142 "source/parser/TextFileParser.rl"
										{fsm->te = p+1;{
#line 142 "source/parser/TextFileParser.rl"
												if (configuration.css_rgb) fsm->colorRgb(); else fsm->clearNumberStacks(); }
										}}
									
#line 889 "/builddir/build/BUILD/gpick-3b17cf9e8b8514bdf16c49ca970e6f47da34e6ae/CMakeFiles/TextFileParser.cpp"
									
									break; 
								}
								case 21:  {
									{
#line 143 "source/parser/TextFileParser.rl"
										{fsm->te = p+1;{
#line 143 "source/parser/TextFileParser.rl"
												if (configuration.css_rgba) fsm->colorRgba(); else fsm->clearNumberStacks(); }
										}}
									
#line 901 "/builddir/build/BUILD/gpick-3b17cf9e8b8514bdf16c49ca970e6f47da34e6ae/CMakeFiles/TextFileParser.cpp"
									
									break; 
								}
								case 22:  {
									{
#line 139 "source/parser/TextFileParser.rl"
										{fsm->te = p;p = p - 1;{
#line 139 "source/parser/TextFileParser.rl"
												if (configuration.short_hex) fsm->colorHexShort(true); }
										}}
									
#line 913 "/builddir/build/BUILD/gpick-3b17cf9e8b8514bdf16c49ca970e6f47da34e6ae/CMakeFiles/TextFileParser.cpp"
									
									break; 
								}
								case 23:  {
									{
#line 141 "source/parser/TextFileParser.rl"
										{fsm->te = p;p = p - 1;{
#line 141 "source/parser/TextFileParser.rl"
												if (configuration.short_hex) fsm->colorHexShort(false); }
										}}
									
#line 925 "/builddir/build/BUILD/gpick-3b17cf9e8b8514bdf16c49ca970e6f47da34e6ae/CMakeFiles/TextFileParser.cpp"
									
									break; 
								}
								case 24:  {
									{
#line 144 "source/parser/TextFileParser.rl"
										{fsm->te = p;p = p - 1;{
#line 144 "source/parser/TextFileParser.rl"
												if (configuration.int_values) fsm->colorValueIntegers(); else fsm->clearNumberStacks(); }
										}}
									
#line 937 "/builddir/build/BUILD/gpick-3b17cf9e8b8514bdf16c49ca970e6f47da34e6ae/CMakeFiles/TextFileParser.cpp"
									
									break; 
								}
								case 25:  {
									{
#line 145 "source/parser/TextFileParser.rl"
										{fsm->te = p;p = p - 1;{
#line 145 "source/parser/TextFileParser.rl"
												if (configuration.int_values) fsm->colorValueIntegers(); else fsm->clearNumberStacks(); }
										}}
									
#line 949 "/builddir/build/BUILD/gpick-3b17cf9e8b8514bdf16c49ca970e6f47da34e6ae/CMakeFiles/TextFileParser.cpp"
									
									break; 
								}
								case 26:  {
									{
#line 146 "source/parser/TextFileParser.rl"
										{fsm->te = p;p = p - 1;{
#line 146 "source/parser/TextFileParser.rl"
												if (configuration.float_values) fsm->colorValues(); else fsm->clearNumberStacks(); }
										}}
									
#line 961 "/builddir/build/BUILD/gpick-3b17cf9e8b8514bdf16c49ca970e6f47da34e6ae/CMakeFiles/TextFileParser.cpp"
									
									break; 
								}
								case 27:  {
									{
#line 149 "source/parser/TextFileParser.rl"
										{fsm->te = p;p = p - 1;{
#line 149 "source/parser/TextFileParser.rl"
												if (configuration.single_line_hash_comments) {fsm->cs = 62;goto _again;}}
										}}
									
#line 973 "/builddir/build/BUILD/gpick-3b17cf9e8b8514bdf16c49ca970e6f47da34e6ae/CMakeFiles/TextFileParser.cpp"
									
									break; 
								}
								case 28:  {
									{
#line 150 "source/parser/TextFileParser.rl"
										{fsm->te = p;p = p - 1;{
#line 150 "source/parser/TextFileParser.rl"
											}
										}}
									
#line 985 "/builddir/build/BUILD/gpick-3b17cf9e8b8514bdf16c49ca970e6f47da34e6ae/CMakeFiles/TextFileParser.cpp"
									
									break; 
								}
								case 29:  {
									{
#line 151 "source/parser/TextFileParser.rl"
										{fsm->te = p;p = p - 1;{
#line 151 "source/parser/TextFileParser.rl"
											}
										}}
									
#line 997 "/builddir/build/BUILD/gpick-3b17cf9e8b8514bdf16c49ca970e6f47da34e6ae/CMakeFiles/TextFileParser.cpp"
									
									break; 
								}
								case 30:  {
									{
#line 152 "source/parser/TextFileParser.rl"
										{fsm->te = p;p = p - 1;{
#line 152 "source/parser/TextFileParser.rl"
											}
										}}
									
#line 1009 "/builddir/build/BUILD/gpick-3b17cf9e8b8514bdf16c49ca970e6f47da34e6ae/CMakeFiles/TextFileParser.cpp"
									
									break; 
								}
								case 31:  {
									{
#line 139 "source/parser/TextFileParser.rl"
										{p = ((fsm->te))-1;
											{
#line 139 "source/parser/TextFileParser.rl"
												if (configuration.short_hex) fsm->colorHexShort(true); }
										}}
									
#line 1022 "/builddir/build/BUILD/gpick-3b17cf9e8b8514bdf16c49ca970e6f47da34e6ae/CMakeFiles/TextFileParser.cpp"
									
									break; 
								}
								case 32:  {
									{
#line 149 "source/parser/TextFileParser.rl"
										{p = ((fsm->te))-1;
											{
#line 149 "source/parser/TextFileParser.rl"
												if (configuration.single_line_hash_comments) {fsm->cs = 62;goto _again;}}
										}}
									
#line 1035 "/builddir/build/BUILD/gpick-3b17cf9e8b8514bdf16c49ca970e6f47da34e6ae/CMakeFiles/TextFileParser.cpp"
									
									break; 
								}
								case 33:  {
									{
#line 151 "source/parser/TextFileParser.rl"
										{p = ((fsm->te))-1;
											{
#line 151 "source/parser/TextFileParser.rl"
											}
										}}
									
#line 1048 "/builddir/build/BUILD/gpick-3b17cf9e8b8514bdf16c49ca970e6f47da34e6ae/CMakeFiles/TextFileParser.cpp"
									
									break; 
								}
								case 34:  {
									{
#line 152 "source/parser/TextFileParser.rl"
										{p = ((fsm->te))-1;
											{
#line 152 "source/parser/TextFileParser.rl"
											}
										}}
									
#line 1061 "/builddir/build/BUILD/gpick-3b17cf9e8b8514bdf16c49ca970e6f47da34e6ae/CMakeFiles/TextFileParser.cpp"
									
									break; 
								}
								case 35:  {
									{
#line 1 "NONE"
										{switch( fsm->act ) {
												case 3:  {
													p = ((fsm->te))-1;
													{
#line 140 "source/parser/TextFileParser.rl"
														if (configuration.full_hex) fsm->colorHexFull(false); }
													break; 
												}
												case 4:  {
													p = ((fsm->te))-1;
													{
#line 141 "source/parser/TextFileParser.rl"
														if (configuration.short_hex) fsm->colorHexShort(false); }
													break; 
												}
												case 7:  {
													p = ((fsm->te))-1;
													{
#line 144 "source/parser/TextFileParser.rl"
														if (configuration.int_values) fsm->colorValueIntegers(); else fsm->clearNumberStacks(); }
													break; 
												}
												case 9:  {
													p = ((fsm->te))-1;
													{
#line 146 "source/parser/TextFileParser.rl"
														if (configuration.float_values) fsm->colorValues(); else fsm->clearNumberStacks(); }
													break; 
												}
												case 10:  {
													p = ((fsm->te))-1;
													{
#line 147 "source/parser/TextFileParser.rl"
														if (configuration.single_line_c_comments) {fsm->cs = 62;goto _again;}}
													break; 
												}
												case 11:  {
													p = ((fsm->te))-1;
													{
#line 148 "source/parser/TextFileParser.rl"
														if (configuration.multi_line_c_comments) {fsm->cs = 60;goto _again;}}
													break; 
												}
												case 14:  {
													p = ((fsm->te))-1;
													{
#line 151 "source/parser/TextFileParser.rl"
													}
													break; 
												}
												case 15:  {
													p = ((fsm->te))-1;
													{
#line 152 "source/parser/TextFileParser.rl"
													}
													break; 
												}
											}}
									}
									
#line 1128 "/builddir/build/BUILD/gpick-3b17cf9e8b8514bdf16c49ca970e6f47da34e6ae/CMakeFiles/TextFileParser.cpp"
									
									break; 
								}
							}
							_nacts -= 1;
							_acts += 1;
						}
						
					}
					
					_again: {}
					if ( p == eof ) {
						if ( fsm->cs >= 63 )
							goto _out;
					}
					else {
						_acts = ( _text_file_actions + (_text_file_to_state_actions[fsm->cs]));
						_nacts = (unsigned int)(*( _acts));
						_acts += 1;
						while ( _nacts > 0 ) {
							switch ( (*( _acts)) ) {
								case 8:  {
									{
#line 1 "NONE"
										{fsm->ts = 0;}}
									
#line 1155 "/builddir/build/BUILD/gpick-3b17cf9e8b8514bdf16c49ca970e6f47da34e6ae/CMakeFiles/TextFileParser.cpp"
									
									break; 
								}
							}
							_nacts -= 1;
							_acts += 1;
						}
						
						if ( fsm->cs != 0 ) {
							p += 1;
							goto _resume;
						}
					}
					_out: {}
				}
				
#line 189 "source/parser/TextFileParser.rl"
				
				if (fsm->cs == text_file_error) {
					parse_error = true;
					text_file.syntaxError(fsm->line, fsm->ts - fsm->buffer - fsm->line_start, fsm->line, fsm->te - fsm->buffer - fsm->line_start);
					break;
				}
				if (fsm->ts == 0){
					have = 0;
					fsm->line_start -= sizeof(fsm->buffer);
				}else{
					have = pe - fsm->ts;
					memmove(fsm->buffer, fsm->ts, have);
					int buffer_movement = fsm->ts - fsm->buffer;
					fsm->te -= buffer_movement;
					fsm->line_start -= buffer_movement;
					fsm->ts = fsm->buffer;
					fsm->buffer_offset += fsm->ts - fsm->buffer;
				}
			}else{
				break;
			}
		}
		return parse_error == false;
	}
	
}
